{% extends "base_login.html" %}
{% load i18n static %}

{% block extra_style %}
<link rel="stylesheet" type="text/css" href="{% static 'shibboleth_eds/idpselect.css' %}"/>
{% endblock %}

{% block main_content %}


<div id="idpSelect"></div>

<div id="idPExplanation">

{% if LANGUAGE_CODE == 'de' %}
<p>Die HU-Box verwendet die zentrale Einmal-Anmeldung (Single Sign-On per Shibboleth). W&auml;hlen Sie bitte Ihre Heimatinstitution aus und melden sich dort an. Shibboleth &uuml;bertr&auml;gt die angezeigten und notwendigen Daten an die HU-Box.</p>
{% else %}
<p>The HU-Box uses the central single sign-on via Shibboleth. Please select your home organization and login there. Shibboleth transfers the displayed and necessary data to the HU-Box.</p>
{% endif %}

</div>

<noscript>
    <!-- If you need to care about non javascript browsers you will need to 
         generate a hyperlink to a non-js DS.

         To build you will need:
             - URL:  The base URL of the DS you use
             - EI: Your entityId, URLencoded.  You can get this from the line that 
               this page is called with.
             - RET: Your return address dlib-adidp.ucs.ed.ac.uk. Again you can get
               this from the page this is called with, but beware of the 
               target%3Dcookie%253A5269905f bit..

        < href=${URL}?entityID=${EI}&return=${RET}
     -->

    Your Browser does not support javascript. Please use
    <a href="{{ non_js_url }}">this link</a>.

  </noscript>
{% endblock %}

{% block extra_script %}
<script src="idpselect_config.js" type="text/javascript" language="javascript"></script>
<script src="{% static 'shibboleth_eds/idpselect.js' %}" type="text/javascript" language="javascript"></script>


{% endblock %}
